pub enum SP1Proof {
Core(Vec<ShardProof<SP1GlobalContext, SP1PcsProofInner>>),
Compressed(Box<SP1RecursionProof<SP1GlobalContext, SP1PcsProofInner>>),
Plonk(PlonkBn254Proof),
Groth16(Groth16Bn254Proof),
}Expand description
A proof generated by the SP1 RISC-V zkVM.
Variants
Core(Vec<ShardProof<SP1GlobalContext, SP1PcsProofInner>>)
A proof generated by the core proof mode.
The proof size scales linearly with the number of cycles.
Compressed(Box<SP1RecursionProof<SP1GlobalContext, SP1PcsProofInner>>)
A proof generated by the compress proof mode.
The proof size is constant, regardless of the number of cycles.
Plonk(PlonkBn254Proof)
A proof generated by the Plonk proof mode.
Groth16(Groth16Bn254Proof)
A proof generated by the Groth16 proof mode.
Implementations
Sourceimpl SP1Proof
impl SP1Proof
pub fn try_as_core( self, ) -> Option<Vec<ShardProof<SP1GlobalContext, SP1PcsProofInner>>>
pub const fn try_as_core_ref( &self, ) -> Option<&Vec<ShardProof<SP1GlobalContext, SP1PcsProofInner>>>
pub fn try_as_core_mut( &mut self, ) -> Option<&mut Vec<ShardProof<SP1GlobalContext, SP1PcsProofInner>>>
pub fn try_as_compressed( self, ) -> Option<Box<SP1RecursionProof<SP1GlobalContext, SP1PcsProofInner>>>
pub const fn try_as_compressed_ref( &self, ) -> Option<&Box<SP1RecursionProof<SP1GlobalContext, SP1PcsProofInner>>>
pub fn try_as_compressed_mut( &mut self, ) -> Option<&mut Box<SP1RecursionProof<SP1GlobalContext, SP1PcsProofInner>>>
pub fn try_as_plonk(self) -> Option<PlonkBn254Proof>
pub const fn try_as_plonk_ref(&self) -> Option<&PlonkBn254Proof>
pub fn try_as_plonk_mut(&mut self) -> Option<&mut PlonkBn254Proof>
pub fn try_as_groth_16(self) -> Option<Groth16Bn254Proof>
pub const fn try_as_groth_16_ref(&self) -> Option<&Groth16Bn254Proof>
pub fn try_as_groth_16_mut(&mut self) -> Option<&mut Groth16Bn254Proof>